@@ -11,6 +11,7 @@ use sqlx_core::value::ValueRef;
 use crate::convert::{JsonCodec, RefJsonCodec, ResultCodec};
 
 use crate::{new_json_option_into};
+use crate::types::DateStringCheck;
 
 impl<'r> JsonCodec for sqlx_core::mssql::MssqlValueRef<'r> {
     fn try_to_json(self) -> crate::Result<serde_json::Value> {
@@ -49,16 +50,18 @@ impl<'r> JsonCodec for sqlx_core::mssql::MssqlValueRef<'r> {
                 return Ok(new_json_option_into!(r));
             }
 
-            //TODO  "DATE" | "TIME" | "DATETIME" | "TIMESTAMP" => {
-            //     let r: Option<String> = Decode::<'_, Mssql>::decode(self)?;
-            //     return Ok(json!(r));
-            // }
-
-            //TODO "NEWDECIMAL" => {
-            //     let r: Option<String> = Decode::<'_, Mssql>::decode(self)?;
-            //     return Ok(json!(r));
-            // }
-
+            "DATE" | "TIME" | "DATETIME" | "TIMESTAMP" => {
+                let r: Option<String> = Decode::<'_, Mssql>::decode(self)?;
+                if let Some(mut v) = r {
+                    v.check();
+                    return Ok(serde_json::Value::String(v));
+                }
+                return Ok(serde_json::Value::Null);
+            }
+            "NEWDECIMAL" => {
+                let r: Option<String> = Decode::<'_, Mssql>::decode(self)?;
+                return Ok(json!(r));
+            }
             // you can use already supported types to decode this
             _ => {
                 return Err(crate::Error::from(format!(
